@@ -726,10 +726,10 @@ IMPL_FUNC(void, loadMaterialsFromRocklist(const std::string& file,
   if (Escale > 0) {
     Emin=1e10;
     for (size_t i=0;i<cache.size();++i)
-      Emin = std::min(Emin,((Isotropic*)cache[i].get())->getE());
+      Emin = std::min(Emin,static_cast<Isotropic*>(cache[i].get())->getE());
     for (size_t i=0;i<cache.size();++i) {
-      double lE = ((Isotropic*)cache[i].get())->getE();
-      ((Isotropic*)cache[i].get())->setE(lE*Escale/Emin);
+      double lE = static_cast<Isotropic*>(cache[i].get())->getE();
+      static_cast<Isotropic*>(cache[i].get())->setE(lE*Escale/Emin);
     }
   }
   std::vector<double> volume;
@@ -1074,11 +1074,7 @@ IMPL_FUNC(void, solve(int loadcase))
 {
   try {
     Dune::InverseOperatorResult r;
-#if DUNE_VERSION_NEWER(DUNE_ISTL, 2, 7)
     u[loadcase].resize(b[loadcase].size());
-#else
-    u[loadcase].resize(b[loadcase].size(), false);
-#endif
     u[loadcase] = 0;
     int solver=0;
 #ifdef HAVE_OPENMP
@@ -1088,7 +1084,7 @@ IMPL_FUNC(void, solve(int loadcase))
     tsolver[solver]->apply(u[loadcase], b[loadcase], r);
 
     std::cout << "\tsolution norm: " << u[loadcase].two_norm() << std::endl;
-  } catch (Dune::ISTLError& e) {
+  } catch (const Dune::ISTLError& e) {
     std::cerr << "exception thrown " << e << std::endl;
   }
 }
